From 540c3e482e90c7c428b7c6684c1527fc412a2085 Mon Sep 17 00:00:00 2001
From: Joel Capitao <jcapitao@redhat.com>
Date: Mon, 31 May 2021 17:04:06 +0200
Subject: [PATCH] remove sorted_set usage
---
lib/semantic_puppet/dependency/graph_node.rb | 4 ++--
spec/unit/semantic_puppet/dependency_spec.rb | 10 +++++-----
2 files changed, 7 insertions(+), 7 deletions(-)
diff --git a/spec/unit/semantic_puppet/dependency_spec.rb b/spec/unit/semantic_puppet/dependency_spec.rb
index f86dc73..f314aba 100644
--- a/spec/unit/semantic_puppet/dependency_spec.rb
+++ b/spec/unit/semantic_puppet/dependency_spec.rb
@@ -93,8 +93,8 @@ describe SemanticPuppet::Dependency do
)
result = SemanticPuppet::Dependency.query('foo' => '1.0.0', 'bar' => '1.0.0')
- expect(result.dependencies['foo']).to eql SortedSet.new([ foo ])
- expect(result.dependencies['bar']).to eql SortedSet.new([ bar ])
+ expect(result.dependencies['foo']).to eql [foo]
+ expect(result.dependencies['bar']).to eql [bar]
end
it 'populates all returned ModuleReleases with related dependencies' do
@@ -105,9 +105,9 @@ describe SemanticPuppet::Dependency do
)
result = SemanticPuppet::Dependency.query('foo' => '1.0.0')
- expect(result.dependencies['foo']).to eql SortedSet.new([ foo ])
- expect(foo.dependencies['bar']).to eql SortedSet.new([ bar ])
- expect(bar.dependencies['baz']).to eql SortedSet.new([ baz ])
+ expect(result.dependencies['foo']).to eql [foo]
+ expect(foo.dependencies['bar']).to eql [bar]
+ expect(bar.dependencies['baz']).to eql [ baz]
end
end
diff --git a/lib/semantic_puppet/dependency/graph_node.rb b/lib/semantic_puppet/dependency/graph_node.rb
index 51416c8..9ca312d 100644
--- a/lib/semantic_puppet/dependency/graph_node.rb
+++ b/lib/semantic_puppet/dependency/graph_node.rb
@@ -33,10 +33,10 @@ module SemanticPuppet
end
# @api internal
# @return [{ String => SortedSet<GraphNode> }] the satisfactory
# dependency nodes
def dependencies
- @_dependencies ||= Hash.new { |h, k| h[k] = SortedSet.new }
+ @_dependencies ||= Hash.new { |h, k| h[k] = Array.new }
end
# Adds the given dependency name to the list of dependencies.
@@ -33,10 +33,10 @@ module SemanticPuppet
end
# @api internal
- # @return [{ String => SortedSet<GraphNode> }] the satisfactory
+ # @return [{ String => Array<GraphNode> }] the satisfactory
# dependency nodes
def dependencies
--
2.31.1